package com.fs.his.mapper;

import java.util.List;
import com.fs.his.domain.FsMaterialGroup;

/**
 * 素材分组Mapper接口
 * 
 * @author fs
 * @date 2023-07-06
 */
public interface FsMaterialGroupMapper 
{
    /**
     * 查询素材分组
     * 
     * @param groupId 素材分组主键
     * @return 素材分组
     */
    public FsMaterialGroup selectFsMaterialGroupByGroupId(Long groupId);

    /**
     * 查询素材分组列表
     * 
     * @param fsMaterialGroup 素材分组
     * @return 素材分组集合
     */
    public List<FsMaterialGroup> selectFsMaterialGroupList(FsMaterialGroup fsMaterialGroup);

    /**
     * 新增素材分组
     * 
     * @param fsMaterialGroup 素材分组
     * @return 结果
     */
    public int insertFsMaterialGroup(FsMaterialGroup fsMaterialGroup);

    /**
     * 修改素材分组
     * 
     * @param fsMaterialGroup 素材分组
     * @return 结果
     */
    public int updateFsMaterialGroup(FsMaterialGroup fsMaterialGroup);

    /**
     * 删除素材分组
     * 
     * @param groupId 素材分组主键
     * @return 结果
     */
    public int deleteFsMaterialGroupByGroupId(Long groupId);

    /**
     * 批量删除素材分组
     * 
     * @param groupIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteFsMaterialGroupByGroupIds(Long[] groupIds);
}
